{% extends "catalogue/detail.html" %}

{% block product_review %}
{% if review %}		
    <h4 id="review-{{ review.pk }}"> {{ review.title }} </h4>
    <p> Score: {{ review.score|floatformat:1 }} / 5.0</p>
    <p> Comments: {{ review.body }}</p>						
{% endif %}
{% endblock %}
