from oscar.apps.partner.tests.model_tests import *
from oscar.apps.partner.tests.import_catalogue import *

__test__ = {
    'model_tests': [model_tests],
    'import_catalogue': [import_catalogue],
}